==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/sv.js <==
OC.L10N.register(
    "serverinfo",
    {
    "Load average" : "Genomsnittsanvändning",
    "Last minute" : "Senaste minuten",
    "Memory info not available" : "Minnesinformation ej tillgänglig",
    "Total" : "Totalt",
    "Current usage" : "Nuvarande användning",
    "Users" : "Användare",
    "Groups" : "Grupper",
    "Links" : "Länkar",
    "Federated sent" : "Sammankopplingar skickade",
    "Federated received" : "Sammankopplingar mottagna",
    "Last 24 hours" : "Senaste 24 timmarna",
    "Last 1 hour" : "Senaste timmen",
    "Last 5 mins" : "Senaste 5 minuterna",
    "Monitoring" : "Övervakning",
    "CPU load" : "CPU-användning",
    "Memory usage" : "Minnesanvändning",
    "Active users" : "Aktiva användare",
    "Shares" : "Delningar",
    "Storage" : "Lagring",
    "Users:" : "Användare:",
    "Files:" : "Filer:",
    "PHP" : "PHP",
    "Version:" : "Version:",
    "Memory Limit:" : "Minneskapacitetsgräns:",
    "Max Execution Time:" : "Längsta körningstid:",
    "Upload max size:" : "Största uppladdningsstorlek:",
    "Database" : "Databas",
    "Type:" : "Typ:",
    "Size:" : "Storlek:",
    "External monitoring tool" : "Externt övervakningsverktyg",
    "You can connect an external monitoring tool by using this end point: " : "Du kan ansluta ett externt övervakningsverktyg genom att använda denna adress:",
    "Server info" : "Serverinformation",
    "You can connect a external monitoring tool by using this end point: " : "Du kan ansluta ett externt övervakningsverktyg genom att använda denna ändpunkt:"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-14.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/sv.js <==
OC.L10N.register(
    "serverinfo",
    {
    "Load average" : "Genomsnittsanvändning",
    "Last minute" : "Senaste minuten",
    "Memory info not available" : "Minnesinformation ej tillgänglig",
    "Total" : "Totalt",
    "Current usage" : "Nuvarande användning",
    "Users" : "Användare",
    "Groups" : "Grupper",
    "Links" : "Länkar",
    "Federated sent" : "Sammankopplingar skickade",
    "Federated received" : "Sammankopplingar mottagna",
    "Last 24 hours" : "Senaste 24 timmarna",
    "Last 1 hour" : "Senaste timmen",
    "Last 5 mins" : "Senaste 5 minuterna",
    "Copy" : "Kopiera",
    "Copied!" : "Kopierat!",
    "Not supported!" : "Stöds ej!",
    "Press ⌘-C to copy." : "Tryck ⌘-C för att kopiera.",
    "Press Ctrl-C to copy." : "Tryck Ctrl-C för att kopiera.",
    "Monitoring" : "Övervakning",
    "CPU load" : "CPU-användning",
    "Memory usage" : "Minnesanvändning",
    "Active users" : "Aktiva användare",
    "Shares" : "Delningar",
    "Storage" : "Lagring",
    "Users:" : "Användare:",
    "Files:" : "Filer:",
    "Version:" : "Version:",
    "PHP" : "PHP",
    "Memory Limit:" : "Minneskapacitetsgräns:",
    "Max Execution Time:" : "Längsta körningstid:",
    "Upload max size:" : "Största uppladdningsstorlek:",
    "Database" : "Databas",
    "Type:" : "Typ:",
    "Size:" : "Storlek:",
    "External monitoring tool" : "Externt övervakningsverktyg",
    "You can connect an external monitoring tool by using this end point: " : "Du kan ansluta ett externt övervakningsverktyg genom att använda denna adress:"
},
"nplurals=2; plural=(n != 1);");
